"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.createMeshHTTPHandler = void 0;
const graphql_1 = require("graphql");
const graphql_yoga_1 = require("graphql-yoga");
const fusion_runtime_1 = require("@graphql-mesh/fusion-runtime");
const server_1 = require("@whatwg-node/server");
function createMeshHTTPHandler(config) {
    let handlerImportFn;
    if (config.handlers != null) {
        if (typeof config.handlers === 'function') {
            handlerImportFn = config.handlers;
        }
        else {
            handlerImportFn = (handlerName) => config.handlers[handlerName];
        }
    }
    else {
        handlerImportFn = defaultHandlerImport;
    }
    let fetchAPI = config.fetchAPI;
    // eslint-disable-next-line prefer-const
    let logger;
    function defaultHandlerImport(handlerName) {
        const omnigraphPackageName = `@omnigraph/${handlerName}`;
        logger.info(`Loading ${omnigraphPackageName}`);
        return Promise.resolve(`${omnigraphPackageName}`).then(s => __importStar(require(s)));
    }
    const yoga = (0, graphql_yoga_1.createYoga)({
        fetchAPI: config.fetchAPI,
        logging: config.logging,
        plugins: [
            ...(config.plugins || []),
            (0, fusion_runtime_1.useSupergraph)({
                getSupergraph() {
                    if (typeof config.supergraph === 'function') {
                        return config.supergraph();
                    }
                    if ((0, graphql_1.isSchema)(config.supergraph)) {
                        return config.supergraph;
                    }
                    if (typeof config.supergraph === 'string') {
                        let url = config.supergraph;
                        if (url.startsWith('.')) {
                            url = `file:///${url}`;
                        }
                        yoga.logger.info(`Fetching Supergraph from ${url}`);
                        return fetchAPI
                            .fetch(config.supergraph, {
                            headers: config.schemaHeaders,
                        })
                            .then(res => res.text())
                            .then(schemaString => (0, graphql_1.buildSchema)(schemaString, {
                            assumeValid: true,
                            assumeValidSDL: true,
                            noLocation: true,
                        }));
                    }
                    return (0, graphql_1.buildASTSchema)(config.supergraph, {
                        assumeValid: true,
                        assumeValidSDL: true,
                    });
                },
                getExecutorFromHandler(handlerName, handlerOptions, getSubgraph) {
                    function handleImportResult(importRes) {
                        const getSubgraphExecutor = importRes.getSubgraphExecutor;
                        if (!getSubgraphExecutor) {
                            logger.error(`getSubgraphExecutor is not exported from the handler: ${handlerName}`);
                            throw new Error(`getSubgraphExecutor is not exported from the handler: ${handlerName}`);
                        }
                        return getSubgraphExecutor({
                            getSubgraph,
                            options: handlerOptions,
                        });
                    }
                    const importRes$ = handlerImportFn(handlerName);
                    if ((0, server_1.isPromise)(importRes$)) {
                        return importRes$.then(handleImportResult);
                    }
                    return handleImportResult(importRes$);
                },
                polling: config.polling,
            }),
        ],
        cors: config.cors,
        graphiql: config.graphiql,
        batching: config.batching,
    });
    fetchAPI ||= yoga.fetchAPI;
    logger = yoga.logger;
    return yoga;
}
exports.createMeshHTTPHandler = createMeshHTTPHandler;
