import { type DocumentNode, type GraphQLSchema } from 'graphql';
import { FetchAPI, YogaServerOptions, type BatchingOptions, type Plugin } from 'graphql-yoga';
import type { GraphiQLOptionsOrFactory } from 'graphql-yoga/typings/plugins/use-graphiql';
import { type SupergraphPlugin } from '@graphql-mesh/fusion-runtime';
import type { CORSPluginOptions } from '@whatwg-node/server/typings/plugins/useCors';
export type MeshHTTPPlugin<TServerContext> = Plugin<TServerContext> & SupergraphPlugin;
export interface MeshHTTPHandlerConfiguration<TServerContext> {
    /**
     * Path to the Supergraph Schema
     */
    supergraph: string | DocumentNode | GraphQLSchema | (() => Promise<string | DocumentNode | GraphQLSchema>);
    /**
     * Headers to be sent to the Supergraph Schema endpoint
     */
    schemaHeaders?: Record<string, string>;
    /**
     * Polling interval in milliseconds
     */
    polling?: number;
    /**
     * Plugins
     */
    plugins?: MeshHTTPPlugin<TServerContext>[];
    /**
     * Configuration for CORS
     */
    cors?: CORSPluginOptions<TServerContext>;
    /**
     * Show GraphiQL
     */
    graphiql?: GraphiQLOptionsOrFactory<TServerContext>;
    /**
     *  Enable and define a limit for [Request Batching](https://github.com/graphql/graphql-over-http/blob/main/rfcs/Batching.md)
     */
    batching?: BatchingOptions;
    /**
     * Imported handlers
     */
    handlers?: Record<string, any> | ((handlerName: string) => Promise<any> | any);
    /**
     * WHATWG compatible Fetch implementation
     */
    fetchAPI?: FetchAPI;
    /**
     * Logger
     */
    logging?: YogaServerOptions<TServerContext, {}>['logging'];
}
export declare function createMeshHTTPHandler<TServerContext>(config: MeshHTTPHandlerConfiguration<TServerContext>): import("graphql-yoga").YogaServerInstance<TServerContext, {}>;
